@@ -36,10 +36,13 @@ def _normalize_name(name: str) -> str:
 
 
 class Color:
-    def __init__(self, color: Union[str, RGBTuple]) -> None:
+    def __init__(self, color: Union["Color", str, RGBTuple]) -> None:
         self.__name = ""
         self.__is_color_code_src = False
 
+        if color is None:
+            raise TypeError("color must be one of Color/str/RGBTuple")
+
         if isinstance(color, str):
             color = _normalize_name(color)
             try:
@@ -49,10 +52,30 @@ class Color:
 
             return
 
-        self.red, self.green, self.blue = color
-        self.__validate_color_value(self.red)
-        self.__validate_color_value(self.green)
-        self.__validate_color_value(self.blue)
+        try:
+            # from a RGBTuple instance
+            self.red, self.green, self.blue = color  # type: ignore
+            self.__validate_color_value(self.red)
+            self.__validate_color_value(self.green)
+            self.__validate_color_value(self.blue)
+        except TypeError:
+            # from a Color instance
+            self.__name = color.name  # type: ignore
+            self.red, self.green, self.blue = color.red, color.green, color.blue  # type: ignore
+
+    def __eq__(self, other) -> bool:
+        if self.name and other.name:
+            return self.name == other.name
+        elif self.name or other.name:
+            return False
+
+        if all([self.red == other.red, self.green == other.green, self.blue == other.blue]):
+            return True
+
+        return False
+
+    def __ne__(self, other) -> bool:
+        return not self.__eq__(other)
 
     def __repr__(self) -> str:
         items = [
@@ -95,6 +118,9 @@ class Color:
     def color_code(self) -> str:
         return "#{:02x}{:02x}{:02x}".format(self.red, self.green, self.blue)
 
+    def calc_scaler(self) -> int:
+        return self.red + self.green + self.blue
+
     def calc_complementary(self):
         rgb = (self.red, self.green, self.blue)
         n = max(rgb) + min(rgb)
